@@ -466,8 +466,8 @@ on_connection_add_clicked (GtkWidget *w, gpointer null)
 	d = gtk_dialog_new_with_buttons (_("New Connection Type"),
 					 GTK_WINDOW (tool->main_dialog),
 					 GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-					 GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
 					 GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT,
+					 GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
 					 NULL);
 
 	gtk_widget_reparent (table, GTK_DIALOG (d)->vbox);
@@ -544,7 +544,7 @@ static void
 activate_directive_cb (XstDirectiveEntry *entry)
 {
 	gchar *file = entry->data;
-	
+
 	xst_tool_run_set_directive (entry->tool, entry->in_xml, entry->report_sign, entry->directive,
 				    file, "1", NULL);
 	g_free (entry->report_sign);
@@ -554,20 +554,26 @@ void
 on_connection_activate_clicked (GtkWidget *w, gpointer null)
 {
 	XstConnection *cxn;
+	gchar *sign, *file;
+	gboolean modified = xst_dialog_get_modified (tool->main_dialog);
 
 	cxn = connection_list_get_active ();
 	connection_activate (cxn, TRUE);
 
-	if (xst_dialog_get_modified (tool->main_dialog)) {
+	file = (cxn->file)? cxn->file: cxn->dev;
+	sign = g_strdup_printf (_("Activating connection ``%s.''"), cxn->name);
+	xst_tool_queue_directive (tool, activate_directive_cb, file, NULL, NULL, "enable_iface");
+	
+	xst_dialog_set_modified (tool->main_dialog, modified);
+	
+/*	if (xst_dialog_get_modified (tool->main_dialog)) {
 		xst_tool_save (tool);
 		xst_dialog_set_modified (tool->main_dialog, FALSE);
 	} else {
-		gchar *sign, *file;
-		
 		file = (cxn->file)? cxn->file: cxn->dev;
 		sign = g_strdup_printf (_("Activating connection ``%s.''"), cxn->name);
 		xst_tool_queue_directive (tool, activate_directive_cb, file, NULL, NULL, "enable_iface");
-	}
+	}*/
 
 	cxn->activation = ACTIVATION_UP;
 }
@@ -586,20 +592,29 @@ void
 on_connection_deactivate_clicked (GtkWidget *w, gpointer null)
 {
 	XstConnection *cxn;
+	gchar *sign, *file;
+	gboolean modified = xst_dialog_get_modified (tool->main_dialog);
 
 	cxn = connection_list_get_active ();
 	connection_activate (cxn, FALSE);
+	
+	file = (cxn->file)? cxn->file: cxn->dev;
+	sign = g_strdup_printf (_("Deactivating connection ``%s.''"), cxn->name);
+	xst_tool_queue_directive (tool, deactivate_directive_cb, file, NULL, NULL, "enable_iface");
+	
+	xst_dialog_set_modified (tool->main_dialog, modified);
+	
+/*	cxn = connection_list_get_active ();
+	connection_activate (cxn, FALSE);
 
 	if (xst_dialog_get_modified (tool->main_dialog)) {
 		xst_tool_save (tool);
 		xst_dialog_set_modified (tool->main_dialog, FALSE);
 	} else {
-		gchar *sign, *file;
-		
 		file = (cxn->file)? cxn->file: cxn->dev;
 		sign = g_strdup_printf (_("Deactivating connection ``%s.''"), cxn->name);
 		xst_tool_queue_directive (tool, deactivate_directive_cb, file, NULL, NULL, "enable_iface");
-	}
+	}*/
 
 	cxn->activation = ACTIVATION_DOWN;
 }
@@ -610,8 +625,8 @@ on_samba_use_toggled (GtkWidget *w, gpointer null)
 	gboolean active, configured, smb_installed;
 
 	active = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (w));
-	configured = (gboolean) gtk_object_get_data (GTK_OBJECT (tool), "tool_configured");
-	smb_installed = (gboolean) gtk_object_get_data (GTK_OBJECT (tool), "smbinstalled");
+	configured = (gboolean) g_object_get_data (G_OBJECT (tool), "tool_configured");
+	smb_installed = (gboolean) g_object_get_data (G_OBJECT (tool), "smbinstalled");
 	
 	if (configured && !smb_installed && active) {
 		GtkWidget *dialog;
@@ -630,11 +645,14 @@ on_samba_use_toggled (GtkWidget *w, gpointer null)
 		return;
 	}
 
-	if (smb_installed) {
-		xst_dialog_widget_set_user_sensitive (tool->main_dialog, "samba_frame", active);
+	xst_dialog_widget_set_user_sensitive (tool->main_dialog, "description_label", active);
+	xst_dialog_widget_set_user_sensitive (tool->main_dialog, "description", active);
+	xst_dialog_widget_set_user_sensitive (tool->main_dialog, "workgroup_label", active);
+	xst_dialog_widget_set_user_sensitive (tool->main_dialog, "workgroup", active);
+	xst_dialog_widget_set_user_sensitive (tool->main_dialog, "wins_use", active);
+	xst_dialog_widget_set_user_sensitive (tool->main_dialog, "wins_ip", active);
+	if (smb_installed)
 		xst_dialog_modify_cb (w, null);
-	} else
-		xst_dialog_widget_set_user_sensitive (tool->main_dialog, "samba_frame", active);
 }
 
 void
@@ -851,8 +869,8 @@ callbacks_check_gateway_hook (XstDialog *dialog, gpointer data)
 	XstTool *tool;
 
 	tool = XST_TOOL (data);
-	if (!gtk_object_get_data (GTK_OBJECT (tool), "gwdevunsup") &&
-	    gtk_object_get_data (GTK_OBJECT (tool), "gatewaydev"))
+	if (!g_object_get_data (G_OBJECT (tool), "gwdevunsup") &&
+	    g_object_get_data (G_OBJECT (tool), "gatewaydev"))
 		return callbacks_check_manual_gatewaydev (tool);
 
 	connection_default_gw_set_auto (tool);
