@@ -69,7 +69,7 @@ fixup_text_list (GtkWidget *text)
 
 	s = xst_ui_text_view_get_text (GTK_TEXT_VIEW (text));
 
-	for (s2 = strchr (s, '\n'); s2; s2 = strchr (s2, '\n'))
+	for (s2 = (gchar *) strchr (s, '\n'); s2; s2 = (gchar *) strchr (s2, '\n'))
 		*s2 = ' ';
 
 	return s;
@@ -82,7 +82,7 @@ fixdown_text_list (char *s)
 
 	g_return_val_if_fail (s != NULL, NULL);
 
-	for (s2 = strchr (s, ' '); s2; s2 = strchr (s2, ' '))
+	for (s2 = (gchar *) strchr (s, ' '); s2; s2 = (gchar *) strchr (s2, ' '))
 		*s2 = '\n';
 
 	return s;
@@ -298,7 +298,6 @@ on_hosts_alias_changed (GtkTextBuffer *w, gpointer not_used)
 void
 on_hosts_add_clicked (GtkWidget * button, gpointer user_data)
 {
-	GtkWidget *clist;
 	gchar *entry[STATICHOST_LIST_COL_LAST];
 	int row;
 	XstStatichostUI *ui;
@@ -310,7 +309,7 @@ on_hosts_add_clicked (GtkWidget * button, gpointer user_data)
 	entry[STATICHOST_LIST_COL_IP] = gtk_editable_get_chars (GTK_EDITABLE (ui->ip), 0, -1);
 	entry[STATICHOST_LIST_COL_ALIAS] = fixup_text_list (ui->alias);
 
-	hosts_list_append (tool, entry);
+	hosts_list_append (tool, (const gchar**) entry);
 
 	xst_hosts_select_row (entry[STATICHOST_LIST_COL_IP]);
 }
@@ -434,7 +433,7 @@ statichost_list_select_row (GtkTreeSelection *selection, gpointer data)
 }
 
 static GtkWidget *
-statichost_list_new (void)
+statichost_list_new (XstTool *tool)
 {
 	GtkWidget        *treeview;
 	GtkTreeSelection *select;
@@ -442,7 +441,8 @@ statichost_list_new (void)
 
 	model = statichost_list_model_new ();
 
-	treeview = gtk_tree_view_new_with_model (model);
+	treeview = xst_dialog_get_widget (tool->main_dialog, "statichost_list");
+	gtk_tree_view_set_model (GTK_TREE_VIEW (treeview), model);
 	g_object_unref (G_OBJECT (model));
 
 	statichost_list_add_columns (GTK_TREE_VIEW (treeview));
@@ -460,16 +460,11 @@ statichost_list_new (void)
 void
 hosts_init_gui (XstTool *tool)
 {
-	GtkWidget       *container;
 	XstStatichostUI *ui;
 
 	ui = g_new0 (XstStatichostUI, 1);
 
-	container = xst_dialog_get_widget (tool->main_dialog, "statichost_list_sw");
-	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (container),
-					     GTK_SHADOW_ETCHED_IN);
-	ui->list = statichost_list_new ();
-	gtk_container_add (GTK_CONTAINER (container), ui->list);
+	ui->list = statichost_list_new (tool);
 
 	ui->ip = xst_dialog_get_widget (tool->main_dialog, "ip");
 	ui->alias = xst_dialog_get_widget (tool->main_dialog, "alias");
@@ -583,7 +578,7 @@ hosts_list_get_selected (gchar **ip, gchar **alias)
 {
 	gchar *entry[STATICHOST_LIST_COL_LAST];
 
-	if (hosts_list_get (NULL, &entry)) {
+	if (hosts_list_get (NULL, entry)) {
 		*ip = entry[STATICHOST_LIST_COL_IP];
 		*alias = entry[STATICHOST_LIST_COL_ALIAS];
 
