@@ -22,6 +22,7 @@
  * Authors: Hans Petter Jansson <hpj@ximian.com>
  *          Jacob Berkman <jacob@ximian.com>
  *          Chema Celorio <chema@ximian.com>
+ *          Carlos Garnacho Parro <garparr@teleline.es>
  */
 
 #include <config.h>
@@ -29,13 +30,15 @@
 #include <stdio.h>
 #include <ctype.h>
 
+#include <locale.h>
+#include <langinfo.h>
+
 #include <gnome.h>
 #include <glade/glade.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 
 #include "xst.h"
 #include "time-tool.h"
-#include "xst-spin-button.h"
 
 #include "tz.h"
 #include "timeserv.h"
@@ -49,6 +52,8 @@ static void timezone_button_clicked (GtkWidget *w, gpointer data);
 static void update_tz (XstTimeTool *time_tool);
 static void server_button_clicked (GtkWidget *w, gpointer data);
 static void ntp_use_toggled (GtkWidget *w, XstDialog *dialog);
+static void xst_time_calendar_change_cb (GtkCalendar *, gpointer);
+static void on_server_list_element_toggled (GtkCellRendererToggle*, gchar*, gpointer);
 
 static char *ntp_servers[] =
 {
@@ -85,7 +90,7 @@ static char *ntp_servers[] =
 	"ntp.adelaide.edu.au (South Australia)",
 	"ntp.shim.org (Singapore, Asia)",
 	"time.nuri.net (Korea, Asia)",
-	"ntp.cs.mu.oz.au (Melbourne, Austrilia)",
+	"ntp.cs.mu.oz.au (Melbourne, Australia)",
 	"ntp.mel.nml.csiro.au (Melbourne, Australia)",
 	"ntp.nml.csiro.au (Sydney, Australia)",
 	"ntp.per.nml.csiro.au (Perth, Australia)",
@@ -111,26 +116,25 @@ static char *ntp_servers[] =
 	"time1.stupi.se (Stockholm, Sweden)",
 	"goodtime.ijs.si (Ljubljana, Slovenia)",
 	"ntp2.ja.net (UK)",
-	0
+	NULL
 };
 
 static XstDialogSignal signals[] = {
-	{ "calendar",          "day_selected",       xst_dialog_modify_cb },
-	{ "calendar",          "month_changed",      xst_dialog_modify_cb },
-	{ "timezone_button",   "clicked",            timezone_button_clicked },
-	{ "ntp_use",           "toggled",            ntp_use_toggled },
-	{ "timeserver_button", "clicked",            server_button_clicked },
-	{ "location_combo",    "set_focus_child",    xst_dialog_modify_cb },
+	/*	{ "calendar",          "day_selected",       G_CALLBACK (xst_time_calendar_change_cb) },
+		{ "calendar",          "month_changed",      G_CALLBACK (xst_time_calendar_change_cb) },*/
+	{ "timezone_button",   "clicked",            G_CALLBACK (timezone_button_clicked) },
+	{ "ntp_use",           "toggled",            G_CALLBACK (ntp_use_toggled) },
+	{ "timeserver_button", "clicked",            G_CALLBACK (server_button_clicked) },
+	{ "location_combo",    "set_focus_child",    G_CALLBACK (xst_dialog_modify_cb) },
 #warning FIXME
 #if 0
-	{ "tz_combo_entry",    "changed",            update_tz },
+	{ "tz_combo_entry",    "changed",            G_CALLBACK (update_tz) },
 #endif
         /* Changed the Signal for the GtkTreeView --AleX
-	  { "ntp_list",          "selection_changed",  xst_dialog_modify_cb },*/
-	{ "ntp_list2",          "cursor_changed",  xst_dialog_modify_cb },
-//#endif
-	{ "ntp_add_server",    "clicked",            on_ntp_addserver },
-	{ "ntp_add_server",    "clicked",            xst_dialog_modify_cb },
+	   { "ntp_list",          "selection_changed",  xst_dialog_modify_cb },
+	   { "ntp_list2",         "cursor_changed",     G_CALLBACK (xst_dialog_modify_cb) },*/
+	{ "ntp_add_server",    "clicked",            G_CALLBACK (on_ntp_addserver) },
+	{ "ntp_add_server",    "clicked",            G_CALLBACK (xst_dialog_modify_cb) },
 	{ NULL }
 };
 
@@ -150,23 +154,29 @@ xst_time_populate_ntp_list (XstTimeTool *time_tool)
 	/* ntp_list is a GtkTreeView */
 	ntp_list = xst_dialog_get_widget (tool->main_dialog, "ntp_list2");
 
-
 	/* set the model */
-	store = gtk_list_store_new (1, G_TYPE_STRING);
+	store = gtk_list_store_new (2, G_TYPE_BOOLEAN, G_TYPE_STRING);
 	gtk_tree_view_set_model (GTK_TREE_VIEW (ntp_list),
 				 GTK_TREE_MODEL (store));
-	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (ntp_list), TRUE);
 
+	/* create the first column, it contains 2 cell renderers */
+	column = gtk_tree_view_column_new ();
 
-	/* create the first column */
+	cell = gtk_cell_renderer_toggle_new ();
+	gtk_tree_view_column_pack_start (column, cell, FALSE);
+	gtk_tree_view_column_add_attribute (column, cell, "active", 0);
+	g_object_set_data (G_OBJECT (cell), "tool", tool);
+	g_signal_connect (G_OBJECT (cell), "toggled", G_CALLBACK (on_server_list_element_toggled), store);
+	
 	cell = gtk_cell_renderer_text_new ();
-	column = gtk_tree_view_column_new_with_attributes ("Servers", cell,
-							   "text", 0, NULL);
+	gtk_tree_view_column_pack_end (column, cell, TRUE);
+	gtk_tree_view_column_add_attribute (column, cell, "text", 1);
+
 	gtk_tree_view_append_column (GTK_TREE_VIEW (ntp_list), column);
 	
 	for (i = 0; ntp_servers[i]; i++) {
 		gtk_list_store_append (store, &iter);
-		gtk_list_store_set (store, &iter, 0, ntp_servers[i], -1);
+		gtk_list_store_set (store, &iter, 0, FALSE, 1, ntp_servers[i], -1);
 	}
 }
 
@@ -189,14 +199,13 @@ xst_time_init_timezone (XstTimeTool *time_tool)
 	
 	locs = tz_get_locations (e_tz_map_get_tz_db (tzmap));
 	
-	for (i = 0; i < locs->len; i++) {
+	for (i = 0; g_ptr_array_index (locs, i); i++) {
 		combo_locs = g_list_append (combo_locs,
 					    g_strdup (tz_location_get_zone (g_ptr_array_index (locs, i))));
 	}
 
 	w = xst_dialog_get_widget (tool->main_dialog, "location_combo");
 	gtk_combo_set_popdown_strings (GTK_COMBO (w), combo_locs);
-
 }
 
 #define is_leap_year(yyy) ((((yyy % 4) == 0) && ((yyy % 100) != 0)) || ((yyy % 400) == 0));
@@ -253,89 +262,17 @@ xst_time_update_date (XstTimeTool *tool, gint add)
 }
 #undef is_leap_year
 
-static void
-xst_time_update_hours (XstTimeTool *tool, gint add)
-{
-	gchar buf [3];
-
-	if (add != 0) {
-		tool->hrs += add;
-		if (tool->hrs < 0) {
-			tool->hrs += 24;
-			xst_time_update_date (tool, -1);
-		}
-		if (tool->hrs > 23) {
-			tool->hrs -= 24;
-			xst_time_update_date (tool, 1);
-		}
-	}
-
-	snprintf (buf, 3, "%2d", tool->hrs);
-	gtk_entry_set_text (GTK_ENTRY (tool->hours), buf);
-}
-
-static void
-xst_time_update_minutes (XstTimeTool *tool, gint add)
-{
-	gchar buf [3];
-
-	if (add != 0) {
-		tool->min += add;
-		if (tool->min < 0) {
-			tool->min += 60;
-			xst_time_update_hours (tool, -1);
-		}
-		if (tool->min > 59) {
-			tool->min -= 60;
-			xst_time_update_hours (tool, 1);
-		}
-	}
-
-	snprintf (buf, 3, "%02d", tool->min);
-	gtk_entry_set_text (GTK_ENTRY (tool->minutes), buf);
-}
-
-static void
-xst_time_update_seconds (XstTimeTool *tool, gint add)
-{
-	gchar buf [3];
-	gint start_pos;
-	gint end_pos;
-
-	if (add != 0) {
-		tool->sec += add;
-		if (tool->sec < 0) {
-			tool->sec += 60;
-			xst_time_update_minutes (tool, -1);
-		}
-		if (tool->sec > 59) {
-			tool->sec -= 60;
-			xst_time_update_minutes (tool, 1);
-		}
-	}
-
-	/* We want to keep the selected text when we are 
-	 * ticking.
-	 */
-#warning FIXME
-#if 0
-	I dont think this is needed anymore --James
-	start_pos = GTK_EDITABLE(tool->seconds)->selection_start_pos;
-        end_pos   = GTK_EDITABLE(tool->seconds)->selection_end_pos;
-#endif
-	snprintf (buf, 3, "%02d", tool->sec);
-	gtk_entry_set_text (GTK_ENTRY (tool->seconds), buf);
-	if (GTK_WIDGET_HAS_FOCUS (tool->seconds))
-	    gtk_editable_select_region (GTK_EDITABLE (tool->seconds),
-					start_pos, end_pos);
-}
-
 void
 xst_time_update (XstTimeTool *tool)
 {
-	xst_time_update_seconds (tool, 0);
-	xst_time_update_minutes (tool, 0);
-	xst_time_update_hours   (tool, 0);
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (tool->seconds), (gfloat) tool->sec);
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (tool->minutes), (gfloat) tool->min);
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (tool->hours), (gfloat) tool->hrs);
+	
+	/* we add the 0 if the number is <= 9, it's more pretty */
+	gtk_entry_set_text (GTK_ENTRY (tool->seconds), g_strdup_printf ("%02d", tool->sec));
+	gtk_entry_set_text (GTK_ENTRY (tool->minutes), g_strdup_printf ("%02d", tool->min));
+	gtk_entry_set_text (GTK_ENTRY (tool->hours), g_strdup_printf ("%02d", tool->hrs));
 }
 
 static gboolean
@@ -353,17 +290,10 @@ xst_time_clock_tick (gpointer time_tool)
 	tt = time (NULL);
 	tm = localtime (&tt);
 
-	if (tm->tm_sec != tool->sec) {
-		gint delta;
-		delta = tm->tm_sec - tool->sec;
-		if (delta < 0)
-			delta += 60;
-		xst_time_update_seconds (tool, delta);
-	}
-
+	xst_time_set_full (time_tool, tm);
 	xst_dialog_thaw (xst_tool->main_dialog);
 	tool->ticking = FALSE;
-	
+
 	return TRUE;
 }
 
@@ -398,6 +328,49 @@ timezone_construct_dialog (XstDialog *dialog)
 	return GTK_WIDGET (d);
 }
 
+static void
+on_server_list_element_toggled (GtkCellRendererToggle *cell, gchar *path_str, gpointer data)
+{
+	GtkListStore *store = (GtkListStore *)data;
+	GtkTreeModel *model = GTK_TREE_MODEL (store);
+	GtkTreeIter iter;
+	GtkTreePath *path = gtk_tree_path_new_from_string (path_str);
+	XstTool *tool = g_object_get_data (G_OBJECT (cell), "tool");
+	gboolean toggle;
+	gchar *server, *p;
+	xmlNodePtr root, node;
+
+	root = xst_xml_doc_get_root (tool->config);
+	node = xst_xml_element_find_first (root, "sync");
+	if (!node) 
+		node = xst_xml_element_add (root, "sync");
+
+	gtk_tree_model_get_iter (model, &iter, path);
+	gtk_tree_model_get (model, &iter, 0, &toggle, 1, &server, -1);
+
+	p = (char *) strchr (server, ' ');
+	if (p) 
+		*p = '\0';  /* Kill comments */
+	
+	if (toggle == TRUE) {
+		/* Toggle is set to true, we have to delete entry in XML and set toggle to FALSE */
+		toggle = FALSE;
+		for (node = xst_xml_element_find_first (node, "server"); node != NULL; node = xst_xml_element_find_next (node, "server")) {
+			if (strcmp (server, xst_xml_element_get_content (node)) == 0) 
+				xst_xml_element_destroy (node);
+		}
+	} else {
+		/* Toggle is set to false, we have to add a server entry in the XML and set toggle to TRUE */
+		toggle = TRUE;
+		node = xst_xml_element_add (node, "server");
+				xst_xml_element_set_content (node, server);
+	}
+
+	gtk_list_store_set (store, &iter, 0, toggle, -1);
+	gtk_tree_path_free (path);
+	xst_dialog_modify (tool->main_dialog);
+}
+
 static void
 timezone_button_clicked (GtkWidget *w, gpointer data)
 {
@@ -455,7 +428,7 @@ server_construct_dialog (XstDialog *dialog)
 					      GTK_STOCK_CLOSE,
 					      GTK_RESPONSE_CLOSE, NULL);
 
-	gtk_widget_set_usize (GTK_WIDGET (d), 350, 320);
+	gtk_widget_set_usize (GTK_WIDGET (d), 550, 400);
 
 	content = xst_dialog_get_widget (dialog, "server_dialog_content");
 
@@ -476,21 +449,9 @@ server_button_clicked (GtkWidget *w, gpointer data)
 
 	dialog = XST_DIALOG (data);
 	
-	if (!d) {
-	     /* Taken Out to change from GnomeDialog to GtkDialog --AleX
-		d = xst_dialog_get_widget (XST_DIALOG (data), "Time servers");
-		gnome_dialog_close_hides (GNOME_DIALOG (d), TRUE);
-	      */
+	if (!d) 
 	      d = server_construct_dialog (dialog);
-	}
 
-	gtk_widget_show (d);
-      /* Taken Out in the same manner --AleX
-	gdk_window_show (d->window);
-	gdk_window_raise (d->window);
-
-	gnome_dialog_run_and_close (GNOME_DIALOG (d));
-      */
 	gtk_dialog_run (GTK_DIALOG (d));
 	gtk_widget_hide (d);
 }
@@ -523,16 +484,16 @@ ntp_use_toggled (GtkWidget *w, XstDialog *dialog)
 	gboolean active, configured, ntp_installed;
 
 	active = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (w));
-	configured = (gboolean) gtk_object_get_data (GTK_OBJECT (dialog->tool), "tool_configured");
-	ntp_installed = (gboolean) gtk_object_get_data (GTK_OBJECT (dialog->tool), "ntpinstalled");
+	configured = (gboolean) g_object_get_data (G_OBJECT (dialog->tool), "tool_configured");
+	ntp_installed = (gboolean) g_object_get_data (G_OBJECT (dialog->tool), "ntpinstalled");
 	
 	if (configured && !ntp_installed && active) {
 		GtkWidget *dialog;
 		
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), FALSE);
-		dialog = gnome_ok_dialog (_("You don't have NTP support installed. Please install NTP support\nin the system to enable server synchronization."));
-		gtk_window_set_title (GTK_WINDOW (dialog), _("NTP support missing."));
-		gnome_dialog_run_and_close (GNOME_DIALOG (dialog));
+		dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_INFO, GTK_BUTTONS_CLOSE, _("You don't have NTP support installed. Please install NTP support\nin the system to enable server synchronization."));
+		gtk_dialog_run (GTK_DIALOG (dialog));
+		gtk_widget_destroy (dialog);
 		return;
 	}
 
@@ -554,7 +515,16 @@ xst_time_tool_type_init (XstTimeTool *tool)
 static XstTool *
 xst_time_tool_new (void)
 {
-	return XST_TOOL (gtk_type_new (XST_TYPE_TIME_TOOL));
+	return XST_TOOL (g_type_create_instance (XST_TYPE_TIME_TOOL));
+}
+
+static void
+xst_time_calendar_change_cb (GtkCalendar *calendar, gpointer data)
+{
+	XstTimeTool *tool = (XstTimeTool *)data;
+
+	xst_time_clock_stop (tool);
+	xst_dialog_modify (XST_TOOL (tool)->main_dialog);
 }
 
 static void 
@@ -568,8 +538,8 @@ xst_time_key_press_event_cb (GtkWidget *widget, GdkEventKey *event, XstTimeTool
 	    (event->keyval == GDK_Down) ||
 	    (event->keyval == GDK_Page_Up) ||
 	    (event->keyval == GDK_Page_Down))
-		gtk_signal_emit_stop_by_name (GTK_OBJECT (widget),
-					      "key_press_event");
+		g_signal_stop_emission_by_name (GTK_OBJECT (widget),
+					        "key_press_event");
 
 	
 	xst_time_clock_stop (tool);
@@ -585,7 +555,7 @@ xst_time_filter (GtkEntry *entry, const gchar *new_text,
 	gchar new_val_string [4];
 	gint new_val;
 	gint max = (widget == tool->hours) ? 24 : 60;
-
+	
 	if (tool->ticking)
 		return;
 	if (length > 1)
@@ -609,7 +579,7 @@ xst_time_filter (GtkEntry *entry, const gchar *new_text,
 	    (strlen (new_val_string) > 2) ||
 	    (new_val >= GPOINTER_TO_INT (max))) {
 		gdk_beep ();
-		gtk_signal_emit_stop_by_name (GTK_OBJECT (entry), "insert_text");
+		g_signal_stop_emission_by_name (GTK_OBJECT (entry), "insert_text");
 		return;
 	}
 
@@ -633,85 +603,76 @@ xst_time_focus_out (GtkWidget *widget, GdkEventFocus *event, XstTimeTool *tool)
 
 	if (widget == tool->seconds) {
 		tool->sec = num;
-		xst_time_update_seconds (tool, 0);
 	} else if (widget == tool->minutes) {
 		tool->min = num;
-		xst_time_update_minutes (tool, 0);
 	} else if (widget == tool->hours) {
 		tool->hrs = num;
-		xst_time_update_hours (tool, 0);
 	}
 
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (widget), (gfloat) num);
 	gtk_signal_emit_stop_by_name (GTK_OBJECT (widget), "focus_out_event");
 }
 
 static void
-xst_time_spin (XstSpinButton *button,
-	       XstTimeTool *tool,
-	       gboolean up)
+xst_time_change (GtkSpinButton *widget, gpointer data)
 {
-	GtkWidget *widget;
-	
-	g_return_if_fail (XST_IS_SPIN_BUTTON (button));
+	XstTimeTool *tool = data;
+	gint value = gtk_spin_button_get_value (widget);
+
+	g_return_if_fail (GTK_IS_SPIN_BUTTON (widget));
 	g_return_if_fail (XST_IS_TIME_TOOL (tool));
 
-	widget = GTK_WIDGET (button);
+	if (widget == GTK_SPIN_BUTTON (tool->seconds)) {
+		if (value > 59) {
+			gtk_spin_button_set_value (widget, value - 60);
+			gtk_spin_button_spin (GTK_SPIN_BUTTON (tool->minutes), GTK_SPIN_STEP_FORWARD, 1);
+		} else if (value < 0) {
+			gtk_spin_button_set_value (widget, value + 60);
+			gtk_spin_button_spin (GTK_SPIN_BUTTON (tool->minutes), GTK_SPIN_STEP_BACKWARD, 1);
+		}
+	} else if (widget == GTK_SPIN_BUTTON (tool->minutes)) {
+		if (value > 59) {
+			gtk_spin_button_set_value (widget, value - 60);
+			gtk_spin_button_spin (GTK_SPIN_BUTTON (tool->hours), GTK_SPIN_STEP_FORWARD, 1);
+		} else if (value < 0) {
+			gtk_spin_button_set_value (widget, value + 60);
+			gtk_spin_button_spin (GTK_SPIN_BUTTON (tool->hours), GTK_SPIN_STEP_BACKWARD, 1);
+		}
+	} else if (widget == GTK_SPIN_BUTTON (tool->hours)) {
+		if (value > 23) {
+			gtk_spin_button_set_value (widget, value - 24);
+			xst_time_update_date (tool, +1);
+		} else if (value < 0) {
+			xst_time_update_date (tool, -1);
+			gtk_spin_button_set_value (widget, value + 24);
+		}
+	}
+
 	xst_dialog_modify (XST_TOOL (tool)->main_dialog);
 	xst_time_clock_stop (tool);
-
-	if (widget == tool->seconds)
-		xst_time_update_seconds (tool, up ? 1 : -1);
-	else if (widget == tool->minutes)
-		xst_time_update_minutes (tool, up ? 1 : -1);
-	else if (widget == tool->hours) 
-		xst_time_update_hours   (tool, up ? 1 : -1);
-}
-	       
-static void
-xst_time_spin_up (XstSpinButton *spin, XstTimeTool *tool)
-{
-	xst_time_spin (spin, tool, TRUE);
-}
-
-static void
-xst_time_spin_down (XstSpinButton *spin, XstTimeTool *tool)
-{
-	xst_time_spin (spin, tool, FALSE);
+	
+	/* We have to set it to 01 instead of 1, it's more pretty */
+	gtk_entry_set_text (GTK_ENTRY (widget), g_strdup_printf ("%02d", value));
 }
 
 static GtkWidget *
-xst_time_spin_button_create (XstTimeTool *tool)
+xst_time_spin_button_create (XstTimeTool *tool, gchar *label)
 {
-	GtkWidget *spin;
-
-	/* what was the point of having a custom spin button?  --James
-	spin = xst_spin_button_new ();
-	*/
-	spin = gtk_spin_button_new_with_range (0, 60, 1);
+	GtkWidget *spin = xst_dialog_get_widget (XST_TOOL (tool)->main_dialog, label);
 	
-#warning FIXME
-#if 0
-	xst_spin_button_set_numeric (XST_SPIN_BUTTON (spin), FALSE);
-	xst_spin_button_set_wrap    (XST_SPIN_BUTTON (spin), TRUE);
-#endif
-
-	gtk_signal_connect (GTK_OBJECT (spin), "insert_text",
-			    GTK_SIGNAL_FUNC (xst_time_filter),
-			    tool);
-	gtk_signal_connect (GTK_OBJECT (spin), "key_press_event",
-			    GTK_SIGNAL_FUNC (xst_time_key_press_event_cb),
-			    tool);
-	gtk_signal_connect_after (GTK_OBJECT (spin), "focus_out_event",
-			    GTK_SIGNAL_FUNC (xst_time_focus_out),
-			    tool);
-
-	gtk_signal_connect (GTK_OBJECT (spin), "spin_up",
-			    GTK_SIGNAL_FUNC (xst_time_spin_up),
-			    tool);
-	gtk_signal_connect (GTK_OBJECT (spin), "spin_down",
-			    GTK_SIGNAL_FUNC (xst_time_spin_down),
-			    tool);
-
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (spin), 0);
+	g_signal_connect (G_OBJECT (spin), "insert_text",
+			  G_CALLBACK (xst_time_filter),
+			  tool);
+	g_signal_connect (G_OBJECT (spin), "key_press_event",
+			  G_CALLBACK (xst_time_key_press_event_cb),
+			  tool);
+	g_signal_connect_after (G_OBJECT (spin), "focus_out_event",
+			        G_CALLBACK (xst_time_focus_out),
+			        tool);
+	g_signal_connect (G_OBJECT (spin), "value-changed",
+			  G_CALLBACK (xst_time_change), 
+			  tool);
 	return spin;
 }
 
@@ -719,24 +680,11 @@ static void
 xst_time_load_widgets (XstTimeTool *tool)
 {
 	XstDialog *dialog = XST_TOOL (tool)->main_dialog;
-	GtkWidget *hbox;
-	GtkWidget *label;
-
-	hbox = xst_dialog_get_widget (dialog, "clock_hbox");
 	
-	tool->seconds = xst_time_spin_button_create (tool);
-	tool->minutes = xst_time_spin_button_create (tool);
-	tool->hours   = xst_time_spin_button_create (tool);
-	tool->map_hover_label = xst_dialog_get_widget (dialog, "location_label");
-
-	gtk_box_pack_start_defaults (GTK_BOX (hbox), tool->hours);
-	label =	gtk_label_new (":");
-	gtk_box_pack_start_defaults (GTK_BOX (hbox), label);
-	gtk_box_pack_start_defaults (GTK_BOX (hbox), tool->minutes);
-	label =	gtk_label_new (":");
-	gtk_box_pack_start_defaults (GTK_BOX (hbox), label);
-	gtk_box_pack_start_defaults (GTK_BOX (hbox), tool->seconds);
-	gtk_widget_show_all (hbox);
+	tool->seconds = xst_time_spin_button_create (tool, "seconds");
+	tool->minutes = xst_time_spin_button_create (tool, "minutes");
+	tool->hours   = xst_time_spin_button_create (tool, "hours");
+	tool->map_hover_label = xst_dialog_get_widget (XST_TOOL (tool)->main_dialog, "location_label");
 }
 
 void
@@ -768,11 +716,17 @@ void
 xst_time_set_full (XstTimeTool *time_tool, struct tm *tm)
 {
 	GtkWidget *calendar_widget;
+	gint day, month, year;
 
 	calendar_widget = xst_dialog_get_widget (XST_TOOL (time_tool)->main_dialog, "calendar");
+	
+	gtk_calendar_get_date (GTK_CALENDAR (calendar_widget), &year, &month, &day);
+	year -= 1900;
 
-	gtk_calendar_select_month (GTK_CALENDAR (calendar_widget), tm->tm_mon, tm->tm_year + 1900);
-	gtk_calendar_select_day   (GTK_CALENDAR (calendar_widget), tm->tm_mday);
+	if ( (tm->tm_year != year) || (tm->tm_mon != month))
+		gtk_calendar_select_month (GTK_CALENDAR (calendar_widget), tm->tm_mon, tm->tm_year + 1900);
+	if (tm->tm_mday != day)
+		gtk_calendar_select_day   (GTK_CALENDAR (calendar_widget), tm->tm_mday);
 
 	time_tool->hrs = tm->tm_hour;
 	time_tool->min = tm->tm_min;
@@ -794,6 +748,31 @@ xst_time_set_from_localtime (XstTimeTool *time_tool, gint correction)
 	xst_time_set_full (time_tool, tm);
 }
 
+void
+xst_time_connect_calendar_signals (XstTimeTool *tool)
+{
+	GtkWidget *calendar = xst_dialog_get_widget (XST_TOOL (tool)->main_dialog, "calendar");
+
+	g_signal_connect (G_OBJECT (calendar), "day_selected", G_CALLBACK (xst_time_calendar_change_cb), tool);
+	g_signal_connect (G_OBJECT (calendar), "month_changed", G_CALLBACK (xst_time_calendar_change_cb), tool);
+}
+
+/* changes the calendar first day depending on the locale configuration */
+static void
+xst_time_configure_calendar (XstTimeTool *tool)
+{
+	gint firstday;
+	GtkWidget *calendar = xst_dialog_get_widget (XST_TOOL (tool)->main_dialog, "calendar");
+
+	setlocale (LC_ALL, "");
+	firstday = (int) *(nl_langinfo (_NL_TIME_FIRST_WEEKDAY));
+
+	if (firstday == 1) 
+		gtk_calendar_display_options (GTK_CALENDAR (calendar), GTK_CALENDAR_WEEK_START_MONDAY | GTK_CALENDAR_SHOW_HEADING | GTK_CALENDAR_SHOW_DAY_NAMES);
+	else
+		gtk_calendar_display_options (GTK_CALENDAR (calendar), GTK_CALENDAR_SHOW_HEADING | GTK_CALENDAR_SHOW_DAY_NAMES);
+}
+
 int
 main (int argc, char *argv[])
 {
@@ -803,8 +782,11 @@ main (int argc, char *argv[])
 	tool = xst_time_tool_new ();
 	xst_tool_construct (tool, "time", _("Time and Date Settings"));
 
+	xst_time_configure_calendar (XST_TIME_TOOL (tool));
+
 	xst_tool_set_xml_funcs (tool, transfer_xml_to_gui, transfer_gui_to_xml, NULL);
 	xst_dialog_connect_signals (tool->main_dialog, signals);
+	xst_time_connect_calendar_signals (XST_TIME_TOOL (tool));
 
 	xst_time_load_widgets (XST_TIME_TOOL (tool));
 	xst_time_populate_ntp_list (XST_TIME_TOOL (tool));
