@@ -36,89 +36,97 @@
 #include "group-settings.h"
 
 extern XstTool *tool;
-static int reply;
-
-GtkWidget *group_settings_all = NULL;
-GtkWidget *group_settings_members = NULL;
 
 static void
-group_fill_users_gtktree (GtkWidget *widget, xmlNodePtr node)
+create_users_lists (xmlNodePtr node, GList **group_settings_all_list, GList **group_settings_members_list)
 {
-	GList *users, *members, *items;
-	
-	members = get_group_users (node);
-	
-	if (widget == group_settings_all) {
-		users = get_list_from_node ("login", node);
-		items = my_g_list_remove_duplicates (users, members);
-	} else {
-		items = members;
-	}
-
-	my_gtktree_list_append_items (GTK_TREE_VIEW (widget), items);
+	*group_settings_members_list = get_group_users (node);
+	*group_settings_all_list = my_g_list_remove_duplicates (get_list_from_node ("login", NODE_USER), *group_settings_members_list);
 }
 
+
 static void
-create_users_lists (void)
+create_users_gtk_trees (void)
 {
+	GtkWidget *group_settings_all = xst_dialog_get_widget (tool->main_dialog, "group_settings_all");
+	GtkWidget *group_settings_members = xst_dialog_get_widget (tool->main_dialog, "group_settings_members");
 	GtkWidget *add_button, *remove_button;
+	GtkTreeSelection *selection;
+	GtkSizeGroup *sizegroup = gtk_size_group_new (GTK_SIZE_GROUP_BOTH);
 	
 	/* We create the widgets, connect signals and attach data if they haven't been created already */
-	if (group_settings_all == NULL) {
-		group_settings_all = create_gtktree_list (xst_dialog_get_widget (tool->main_dialog, "group_settings_all"));
-		gtk_object_set_data (GTK_OBJECT (group_settings_all), "button", "group_settings_add");
-		gtk_signal_connect (GTK_OBJECT (group_settings_all),
-		                    "cursor_changed",
-		                    G_CALLBACK (on_list_select_row),
-		                    NULL);
+	if (g_object_get_data (G_OBJECT (group_settings_all), "button") == NULL) {
+		create_gtk_tree_list (group_settings_all);
+		g_object_set_data (G_OBJECT (group_settings_all), "button", "group_settings_add");
+		selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (group_settings_all));
+		g_signal_connect (G_OBJECT (selection),
+		                  "changed",
+		                  G_CALLBACK (on_list_select_row),
+		                  NULL);
 
-		group_settings_members = create_gtktree_list (xst_dialog_get_widget (tool->main_dialog, "group_settings_members"));
-		gtk_object_set_data (GTK_OBJECT (group_settings_members), "button", "group_settings_remove");
-		gtk_signal_connect (GTK_OBJECT (group_settings_members),
-		                    "cursor_changed",
-		                    G_CALLBACK (on_list_select_row),
-		                    NULL);
+		create_gtk_tree_list (group_settings_members);
+		g_object_set_data (G_OBJECT (group_settings_members), "button", "group_settings_remove");
+		selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (group_settings_members));
+		g_signal_connect (G_OBJECT (selection),
+		                  "changed",
+		                  G_CALLBACK (on_list_select_row),
+		                  NULL);
 		
 		/* We also need to attach some data to the 'add' and 'remove' buttons */
 		add_button = xst_dialog_get_widget (tool->main_dialog, "group_settings_add");
-		gtk_object_set_data (GTK_OBJECT (add_button), "in", group_settings_all);
-		gtk_object_set_data (GTK_OBJECT (add_button), "out", group_settings_members);
+		g_object_set_data (G_OBJECT (add_button), "in", group_settings_all);
+		g_object_set_data (G_OBJECT (add_button), "out", group_settings_members);
 		
 		remove_button = xst_dialog_get_widget (tool->main_dialog, "group_settings_remove");
-		gtk_object_set_data (GTK_OBJECT (remove_button), "in", group_settings_members);
-		gtk_object_set_data (GTK_OBJECT (remove_button), "out", group_settings_all);
+		g_object_set_data (G_OBJECT (remove_button), "in", group_settings_members);
+		g_object_set_data (G_OBJECT (remove_button), "out", group_settings_all);
+
+		/* Add the scrolled windows that contain the trees in the same GtkSizeGroup */
+		gtk_size_group_add_widget (sizegroup, xst_dialog_get_widget (tool->main_dialog, "group_settings_all_container"));
+		gtk_size_group_add_widget (sizegroup, xst_dialog_get_widget (tool->main_dialog, "group_settings_members_container"));
+		
 	}
 }
 
 void
 group_new_prepare (ug_data *gd)
 {
+	GtkWidget *group_settings_all = xst_dialog_get_widget (tool->main_dialog, "group_settings_all");
+	GtkWidget *group_settings_members = xst_dialog_get_widget (tool->main_dialog, "group_settings_members");
 	GtkWidget *widget;
 	gchar     *buf;
-	
-	create_users_lists ();
+	GList *group_settings_members_list = NULL;
+	GList *group_settings_all_list = NULL;
 	
 	/* Fill all users list, don't exclude anything */
-	group_fill_users_gtktree (group_settings_all, gd->node);
+	create_users_gtk_trees ();
+	create_users_lists (gd->node, &group_settings_all_list, &group_settings_members_list);
+	populate_gtk_tree_list (GTK_TREE_VIEW (group_settings_all), group_settings_all_list);
+	
+	/* Attach the GLists to the GtkTreeViews */
+	g_object_set_data (G_OBJECT (group_settings_all), "list", group_settings_all_list);
+	g_object_set_data (G_OBJECT (group_settings_members), "list", group_settings_members_list);
 
 	widget = xst_dialog_get_widget (tool->main_dialog, "group_settings_dialog");
 	gtk_window_set_title (GTK_WINDOW (widget), _("Create New Group"));
 
 	/* Fill in first available gid */
-	buf = (gchar *) find_new_id (gd->node);
+	buf = (gchar *) find_new_id (gd->node, NULL);
 	if (buf) {
 		gtk_spin_button_set_value (GTK_SPIN_BUTTON (xst_dialog_get_widget (tool->main_dialog, "group_settings_gid")), 
 		                           g_strtod (buf, NULL));
 		g_free (buf);
 	}
 
-	gtk_object_set_data (GTK_OBJECT (widget), "data", gd);
+	g_object_set_data (G_OBJECT (widget), "data", gd);
 	gtk_widget_show (widget);
 }
 
 void
 group_settings_dialog_close (void)
 {
+	GtkWidget *group_settings_all = xst_dialog_get_widget (tool->main_dialog, "group_settings_all");
+	GtkWidget *group_settings_members = xst_dialog_get_widget (tool->main_dialog, "group_settings_members");
 	GtkWidget *widget;
 	GtkTreeModel *model;
 	ug_data *gd;
@@ -142,9 +150,9 @@ group_settings_dialog_close (void)
 	
 	/* Clear group data attached to the dialog */
 	widget = xst_dialog_get_widget (tool->main_dialog, "group_settings_dialog");
-	gd = gtk_object_get_data (GTK_OBJECT (widget), "data");
+	gd = g_object_get_data (G_OBJECT (widget), "data");
 	g_free (gd);
-	gtk_object_remove_data (GTK_OBJECT (widget), "data");
+	g_object_steal_data (G_OBJECT (widget), "data");
 	gtk_widget_hide (widget);
 }
 
@@ -208,6 +216,7 @@ is_group_name_valid (xmlNodePtr node, const gchar *name)
 gboolean
 group_update (ug_data *gd)
 {
+	GtkWidget *group_settings_members = xst_dialog_get_widget (tool->main_dialog, "group_settings_members");
 	gchar *name, *gid;
 	GList *users;
 	
@@ -221,7 +230,7 @@ group_update (ug_data *gd)
 		return FALSE;
 	}
 	
-	users = extract_members_list (GTK_TREE_VIEW (group_settings_members));
+	users = g_list_copy (g_object_get_data (G_OBJECT (group_settings_members), "list"));
 	
 	if (gd->is_new) {
 		/* Add new group, update table. */
@@ -239,18 +248,13 @@ group_update (ug_data *gd)
 	return TRUE;
 }
 
-static void
-reply_cb (gint val, gpointer data)
-{
-        reply = val;
-}
-
 static gboolean
 check_group_delete (xmlNodePtr node)
 {
 	gchar *name, *txt;
 	GtkWindow *parent;
-	GnomeDialog *dialog;
+	GtkWidget *dialog;
+	gint reply;
 
 	g_return_val_if_fail (node != NULL, FALSE);
 
@@ -265,48 +269,57 @@ check_group_delete (xmlNodePtr node)
 
 	if (strcmp (name, "root") == 0)
 	{
-		g_free (name);
 		txt = g_strdup (_("The root group must not be deleted."));
-		dialog = GNOME_DIALOG (gnome_error_dialog_parented (txt, parent));
-		gnome_dialog_run (dialog);
+		show_error_message ("group_settings_dialog", txt);
+		g_free (name);
 		g_free (txt);
 		return FALSE;
 	}
 
 	txt = g_strdup_printf (_("Are you sure you want to delete group %s?"), name);
-	dialog = GNOME_DIALOG (gnome_question_dialog_parented (txt, reply_cb, NULL, parent));
-	gnome_dialog_run (dialog);
+	dialog = gtk_message_dialog_new (parent, GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_YES_NO, txt);
+	reply = gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_widget_destroy (dialog);
 	g_free (txt);
 	g_free (name);
 	
-	if (reply)
+	if (reply == GTK_RESPONSE_NO)
 		return FALSE;
         else
 		return TRUE;
 }
 
-void 
+gboolean 
 delete_group (xmlNodePtr node)
 {
-	if (check_group_delete (node))
-	{
-		delete_selected_row (TABLE_GROUP);
+	if (check_group_delete (node)) {
 		xst_xml_element_destroy (node);
-		xst_dialog_modify (tool->main_dialog);
-		groups_table_update_content ();
-		actions_set_sensitive (TABLE_GROUP, FALSE);
-	} 
+		return TRUE;
+	}
+
+	return FALSE;
 }
 
 static void
 group_settings_dialog_prepare (ug_data *gd)
 {
+	GtkWidget *group_settings_all = xst_dialog_get_widget (tool->main_dialog, "group_settings_all");
+	GtkWidget *group_settings_members = xst_dialog_get_widget (tool->main_dialog, "group_settings_members");
 	GtkWidget *w0;
 	gchar *txt, *name;
+	GList *group_settings_all_list = NULL;
+	GList *group_settings_members_list = NULL;
 
 	g_return_if_fail (gd != NULL);
 	
-	create_users_lists ();
+	/* Fill group members */
+	create_users_gtk_trees ();
+	create_users_lists (gd->node, &group_settings_all_list, &group_settings_members_list);
+	populate_gtk_tree_list (GTK_TREE_VIEW (group_settings_members), group_settings_members_list);
+	
+	/* Attach the GLists to the GtkTreeViews */
+	g_object_set_data (G_OBJECT (group_settings_all), "list", group_settings_all_list);
+	g_object_set_data (G_OBJECT (group_settings_members), "list", group_settings_members_list);
 
 	/* Set group name */
 	name = xst_xml_get_child_content (gd->node, "name");
@@ -320,11 +333,8 @@ group_settings_dialog_prepare (ug_data *gd)
 	gtk_widget_set_sensitive (w0, xst_tool_get_access (tool));
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (w0), g_strtod (txt, NULL));
 
-	/* Fill group members */
-	group_fill_users_gtktree (group_settings_members, gd->node);
-
 	/* Fill all users list */
-	group_fill_users_gtktree (group_settings_all, gd->node);
+	populate_gtk_tree_list (GTK_TREE_VIEW (group_settings_all), group_settings_all_list);
 
 	/* Show group settings dialog */
 
@@ -334,7 +344,7 @@ group_settings_dialog_prepare (ug_data *gd)
 	g_free (name);
 	g_free (txt);
 
-	gtk_object_set_data (GTK_OBJECT (w0), "data", gd);
+	g_object_set_data (G_OBJECT (w0), "data", gd);
 	gtk_widget_show (w0);
 }
 
