@@ -33,6 +33,7 @@
 #include "table.h"
 #include "users-table.h"
 #include "groups-table.h"
+#include "profiles-table.h"
 #include "user_group.h"
 #include "callbacks.h"
 #include "user-group-xml.h"
@@ -42,18 +43,14 @@ extern XstTool *tool;
 extern GtkWidget *users_table;
 extern GtkWidget *groups_table;
 
-GtkWidget*
-create_gtk_tree_list (GtkWidget *sw)
+void
+create_gtk_tree_list (GtkWidget *list)
 {
 	GtkTreeModel *model = GTK_TREE_MODEL(gtk_tree_store_new (2, G_TYPE_STRING, G_TYPE_POINTER));
 	GtkTreeSelection *selection;
-	GtkWidget *list;
 	GtkCellRenderer *renderer;
 	
-	list = gtk_tree_view_new_with_model (model);
-	
-	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (list), TRUE);
-	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (list), FALSE);
+	gtk_tree_view_set_model (GTK_TREE_VIEW (list), model);
 	
 	renderer = gtk_cell_renderer_text_new ();
 	
@@ -68,11 +65,6 @@ create_gtk_tree_list (GtkWidget *sw)
 	
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (list));
 	gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
-	
-	gtk_widget_show_all (list);
-	gtk_container_add (GTK_CONTAINER (sw), list);
-	
-	return list;
 }
 
 void
@@ -114,10 +106,11 @@ populate_gtk_tree_list (GtkTreeView *list, GList *items)
 }
 
 void
-construct_tables (void)
+create_tables (void)
 {
-	construct_users_table ();
-	construct_groups_table ();
+	create_users_table ();
+	create_groups_table ();
+	create_profiles_table ();
 }
 
 void 
@@ -131,6 +124,7 @@ populate_all_tables (void)
 {
 	populate_users_table ();
 	populate_groups_table ();
+	populate_profiles_table ();
 }
 
 void 
@@ -150,11 +144,11 @@ xmlNodePtr get_selected_row_node (gint tbl)
 	gint column;
 	
 	switch (tbl) {
-		case TABLE_USER:
+		case NODE_USER:
 			table = GTK_TREE_VIEW (users_table);
 			column = COL_USER_POINTER;
 			break;
-		case TABLE_GROUP:
+		case NODE_GROUP:
 			table = GTK_TREE_VIEW (groups_table);
 			column = COL_GROUP_POINTER;
 			break;
